# -*- coding: utf-8 -*-
"""
Spyder Editor

This is a temporary script file.
"""

def say_hello(name = None):
    if name is None:
        return "Hello, World!"
    else:
        return f"Hello, {name}!"


# -*- coding: utf-8 -*-
"""
Created on Tue Jul 13 19:45:54 2021

@author: jianzhezhen
"""

from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
      name = "helloworldTZ",
      version = "0.0.1",
      description = "Say hello!",
      py_modules = {"helloworldTZ"},
      package_dir = {'': 'src'},
      classifiers = [
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: MIT License",
          "Intended Audience :: Developers",
          "Operating System :: OS Independent",
          ],
      long_description = long_description,
      long_description_content_type = "text/markdown",
      install_requires = [
          "numpy",],
      extras_require = {
          "dev":[
              "pytest>=3.7",
              ],
          },
      url = "http://trevorzhen.com/" ,
      author = "trevorzhen",
      author_email = "trevorzhen@gmail.com",
      include_package_data = True,
      
      )


# -*- coding: utf-8 -*-
"""
Created on Tue Jul 13 22:02:45 2021

@author: jianzhezhen
"""
from helloworldTZ import say_hello

def test_helloworld_no_params():
    assert say_hello() == "Hello, World!"
    
def test_helloworld_with_param():
    assert say_hello("Shiyi") == "Hello, Shiyi!"
